@@ -44,7 +44,7 @@ def developer_contact():
 
 def showHistory():
     """Prints the information of all last sent messages using this program"""
-    file = open("pywhatkit_dbs.txt","r")
+    file = open("pywhatkit_dbs.txt","r",encoding='utf-8')
     content = file.read()
     file.close()
     if content == "--------------------":
@@ -132,7 +132,7 @@ first check it by calling 'check_window()' function'''
     
     date = "%s:%s:%s"%(curr.tm_mday,curr.tm_mon,curr.tm_year)
     time_write = "%s:%s"%(timehr,time_min)
-    file = open("pywhatkit_dbs.txt","a")
+    file = open("pywhatkit_dbs.txt","a",encoding='utf-8')
     file.write("Date: %s\nTime: %s\nPhone number: %s\nMessage: %s"%(date,time_write,phone_no,message))
     file.write("\n--------------------\n")
     file.close()
@@ -253,11 +253,11 @@ if tyme >= 5:
         raise Warning("INTERNET IS SLOW, extraction of information might take longer time")
 
 try :
-    file = open("pywhatkit_dbs.txt","r")
+    file = open("pywhatkit_dbs.txt","r",encoding='utf-8')
     file.close()
 
 except:
-    file = open("pywhatkit_dbs.txt","w")
+    file = open("pywhatkit_dbs.txt","w",encoding='utf-8')
     print("""Hello from the creator of pywhatkit, Ankit Raj Mahapatra.\nKindly do report bugs if any
 What's new:
 1. Removed selenium dependent functions
